.. _all-salt.proxy:

=============
proxy modules
=============

.. currentmodule:: salt.proxy

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    chronos
    cisconso
    esxi
    fx2
    junos
    marathon
    napalm
    nxos
    philips_hue
    rest_sample
    ssh_sample
